--- php-fpm-rev-93/ac/fpm_conf.m4
+++ php-fpm/ac/fpm_conf.m4
@@ -63,16 +63,25 @@
 		php_fpm_port="$PHP_FPM_PORT"
 	fi
 
-	if test -z "$PHP_FPM_CONF" -o "$PHP_FPM_CONF" = "yes" -o "$PHP_FPM_CONF" = "no"; then
+	if test -z "$PHP_FPM_CONF" -o "$PHP_FPM_CONF" = "yes"; then
 		php_fpm_conf_path="/etc/php-fpm.conf"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
+	elif test "$PHP_FPM_CONF" = "no"; then
+		php_fpm_conf_path=""
+		php_fpm_conf=""
+		php_fpm_conf_dir=""
 	else
 		php_fpm_conf_path="$PHP_FPM_CONF"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 	fi
-	php_fpm_conf=`basename $php_fpm_conf_path`
-	php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 
 	if test -z "$PHP_FPM_INIT" -o "$PHP_FPM_INIT" = "yes"; then
-		php_fpm_init_path="/etc/init.d/php-fpm"
+		case $host_os in
+		*bsd* ) php_fpm_init_path="/usr/local/etc/rc.d/php-fpm" ;;
+		* ) php_fpm_init_path="/etc/init.d/php-fpm" ;;
+		esac
 		php_fpm_init=`basename $php_fpm_init_path`
 		php_fpm_init_dir=`dirname $php_fpm_init_path`
 	elif test "$PHP_FPM_INIT" = "no"; then
--- php-fpm-rev-93/ac/Makefile.frag
+++ php-fpm/ac/Makefile.frag
@@ -11,25 +11,48 @@
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_pid_dir)
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_log_dir)
 	@$(INSTALL) -m 0755 $(SAPI_FPM_PATH) $(INSTALL_ROOT)$(php_fpm_bin_path)$(program_suffix)$(EXEEXT)
-	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
-	@$(INSTALL_DATA) sapi/fpm/$(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path)
+
+	@test "$(php_fpm_conf)" && \
+	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
+
+	@test "$(php_fpm_conf)" && \
+	test -f "$(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(INSTALL_DATA) $(INSTALL_ROOT)$(php_fpm_conf_path) $(INSTALL_ROOT)$(php_fpm_conf_path).old
+
+	@test "$(php_fpm_conf)" && \
+	$(INSTALL_DATA) sapi/fpm/$(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path).default && \
+	ln -sf $(INSTALL_ROOT)$(php_fpm_conf_path).default $(INSTALL_ROOT)$(php_fpm_conf_path)
+
 	@echo "Installing PHP FPM man page:      $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1"
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(mandir)/man1
 	@$(INSTALL_DATA) sapi/fpm/$(php_fpm_bin).1 $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "Installing PHP FPM init script:   $(INSTALL_ROOT)$(php_fpm_init_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir)
-	@$(INSTALL) -m 0755 sapi/fpm/init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
-endif
+
+	@test "$(php_fpm_init)" && \
+	echo "Installing PHP FPM init script:   $(INSTALL_ROOT)$(php_fpm_init_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir) && \
+	$(INSTALL) -m 0755 sapi/fpm/init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
+
+	@test -d /etc/nginx/ && \
+	echo "Installing NGINX sample config:   /etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b sapi/fpm/nginx-site-conf.sample /etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/etc/nginx/ && \
+	echo "Installing NGINX sample config:   /usr/local/etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b sapi/fpm/nginx-site-conf.sample /usr/local/etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/nginx/conf/ && \
+	echo "Installing NGINX sample config:   /usr/local/nginx/conf/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b sapi/fpm/nginx-site-conf.sample /usr/local/nginx/conf/nginx-site-conf.sample
+
 	@echo ""
 	@echo "*** FPM Installation complete. ***"
 	@echo ""
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "run:"
-	@echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`"
-	@echo ""
-	@echo "or system equivalent to start the $(php_fpm_init) service."
-	@echo ""
-endif
+
+	@test "$(php_fpm_init)" && \
+	echo "run:" && \
+	echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`" && \
+	echo "" && \
+	echo "or system equivalent to start the $(php_fpm_init) service." && \
+	echo ""
 
--- php-fpm-rev-93/acinclude.m4
+++ php-fpm/acinclude.m4
@@ -436,16 +436,25 @@
 		php_fpm_port="$with_fpm_port"
 	fi
 
-	if test -z "$with_fpm_conf" -o "$with_fpm_conf" = "yes" -o "$with_fpm_conf" = "no"; then
+	if test -z "$with_fpm_conf" -o "$with_fpm_conf" = "yes"; then
 		php_fpm_conf_path="/etc/php-fpm.conf"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
+	elif test "$with_fpm_conf" = "no"; then
+		php_fpm_conf_path=""
+		php_fpm_conf=""
+		php_fpm_conf_dir=""
 	else
 		php_fpm_conf_path="$with_fpm_conf"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 	fi
-	php_fpm_conf=`basename $php_fpm_conf_path`
-	php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 
 	if test -z "$with_fpm_init" -o "$with_fpm_init" = "yes"; then
-		php_fpm_init_path="/etc/init.d/php-fpm"
+		case $host_os in
+		*bsd* ) php_fpm_init_path="/usr/local/etc/rc.d/php-fpm" ;;
+		* ) php_fpm_init_path="/etc/init.d/php-fpm" ;;
+		esac
 		php_fpm_init=`basename $php_fpm_init_path`
 		php_fpm_init_dir=`dirname $php_fpm_init_path`
 	elif test "$with_fpm_init" = "no"; then
--- php-fpm-rev-93/conf/nginx-site-conf.sample.in
+++ php-fpm/conf/nginx-site-conf.sample.in
@@ -5,6 +5,7 @@
 # 
 # 1. set $site_root /path/to/your/website;
 # 2. Rename this file. Copy it to /etc/nginx/sites-available, /etc/nginx/sites-enabled
+#    or otherwise ensure that this file is included by the nginx.conf
 # 3. Restart nginx webserver, and @php_fpm_bin@ service.
 # 
 
--- php-fpm-rev-93/configure
+++ php-fpm/configure
@@ -20593,16 +20593,25 @@
 		php_fpm_port="$with_fpm_port"
 	fi
 
-	if test -z "$with_fpm_conf" -o "$with_fpm_conf" = "yes" -o "$with_fpm_conf" = "no"; then
+	if test -z "$with_fpm_conf" -o "$with_fpm_conf" = "yes"; then
 		php_fpm_conf_path="/etc/php-fpm.conf"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
+	elif test "$with_fpm_conf" = "no"; then
+		php_fpm_conf_path=""
+		php_fpm_conf=""
+		php_fpm_conf_dir=""
 	else
 		php_fpm_conf_path="$with_fpm_conf"
+		php_fpm_conf=`basename $php_fpm_conf_path`
+		php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 	fi
-	php_fpm_conf=`basename $php_fpm_conf_path`
-	php_fpm_conf_dir=`dirname $php_fpm_conf_path`
 
 	if test -z "$with_fpm_init" -o "$with_fpm_init" = "yes"; then
-		php_fpm_init_path="/etc/init.d/php-fpm"
+		case $host_os in
+		*bsd* ) php_fpm_init_path="/usr/local/etc/rc.d/php-fpm" ;;
+		* ) php_fpm_init_path="/etc/init.d/php-fpm" ;;
+		esac
 		php_fpm_init=`basename $php_fpm_init_path`
 		php_fpm_init_dir=`dirname $php_fpm_init_path`
 	elif test "$with_fpm_init" = "no"; then
--- php-fpm-rev-93/m4/Makefile.frag
+++ php-fpm/m4/Makefile.frag
@@ -11,25 +11,48 @@
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_pid_dir)
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_log_dir)
 	@$(INSTALL) -m 0755 $(php_fpm_bin) $(INSTALL_ROOT)$(php_fpm_bin_path)$(program_suffix)$(EXEEXT)
-	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
-	@$(INSTALL_DATA) $(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path)
+
+	@test "$(php_fpm_conf)" && \
+	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
+
+	@test "$(php_fpm_conf)" && \
+	test -f "$(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(INSTALL_DATA) $(INSTALL_ROOT)$(php_fpm_conf_path) $(INSTALL_ROOT)$(php_fpm_conf_path).old
+
+	@test "$(php_fpm_conf)" && \
+	$(INSTALL_DATA) $(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path).default && \
+	ln -sf $(INSTALL_ROOT)$(php_fpm_conf_path).default $(INSTALL_ROOT)$(php_fpm_conf_path)
+
 	@echo "Installing PHP FPM man page:      $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1"
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(mandir)/man1
 	@$(INSTALL_DATA) $(php_fpm_bin).1 $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "Installing PHP FPM init script:   $(INSTALL_ROOT)$(php_fpm_init_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir)
-	@$(INSTALL) -m 0755 init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
-@ENDIF@
+
+	@test "$(php_fpm_init)" && \
+	echo "Installing PHP FPM init script:   $(INSTALL_ROOT)$(php_fpm_init_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir) && \
+	$(INSTALL) -m 0755 init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
+
+	@test -d /etc/nginx/ && \
+	echo "Installing NGINX sample config:   /etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/etc/nginx/ && \
+	echo "Installing NGINX sample config:   /usr/local/etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /usr/local/etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/nginx/conf/ && \
+	echo "Installing NGINX sample config:   /usr/local/nginx/conf/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /usr/local/nginx/conf/nginx-site-conf.sample
+
 	@echo ""
 	@echo "*** FPM Installation complete. ***"
 	@echo ""
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "run:"
-	@echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`"
-	@echo ""
-	@echo "or system equivalent to start the $(php_fpm_init) service."
-	@echo ""
-@ENDIF@
+
+	@test "$(php_fpm_init)" && \
+	echo "run:" && \
+	echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`" && \
+	echo "" && \
+	echo "or system equivalent to start the $(php_fpm_init) service." && \
+	echo ""
 
--- php-fpm-rev-93/Makefile.in
+++ php-fpm/Makefile.in
@@ -737,27 +737,50 @@
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_pid_dir)
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_log_dir)
 	@$(INSTALL) -m 0755 $(php_fpm_bin) $(INSTALL_ROOT)$(php_fpm_bin_path)$(program_suffix)$(EXEEXT)
-	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
-	@$(INSTALL_DATA) $(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path)
+
+	@test "$(php_fpm_conf)" && \
+	@echo "Installing PHP FPM config:        $(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_conf_dir)
+
+	@test "$(php_fpm_conf)" && \
+	test -f "$(INSTALL_ROOT)$(php_fpm_conf_path)" && \
+	$(INSTALL_DATA) $(INSTALL_ROOT)$(php_fpm_conf_path) $(INSTALL_ROOT)$(php_fpm_conf_path).old
+
+	@test "$(php_fpm_conf)" && \
+	$(INSTALL_DATA) $(php_fpm_conf) $(INSTALL_ROOT)$(php_fpm_conf_path).default && \
+	ln -sf $(INSTALL_ROOT)$(php_fpm_conf_path).default $(INSTALL_ROOT)$(php_fpm_conf_path)
+
 	@echo "Installing PHP FPM man page:      $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1"
 	@$(mkinstalldirs) $(INSTALL_ROOT)$(mandir)/man1
 	@$(INSTALL_DATA) $(php_fpm_bin).1 $(INSTALL_ROOT)$(mandir)/man1/$(php_fpm_bin)$(program_suffix).1
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "Installing PHP FPM init script: $(INSTALL_ROOT)$(php_fpm_init_path)"
-	@$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir)
-	@$(INSTALL) -m 0755 init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
-@ENDIF@
+
+	@test "$(php_fpm_init)" && \
+	echo "Installing PHP FPM init script:   $(INSTALL_ROOT)$(php_fpm_init_path)" && \
+	$(mkinstalldirs) $(INSTALL_ROOT)$(php_fpm_init_dir) && \
+	$(INSTALL) -m 0755 init.d.$(php_fpm_init) $(INSTALL_ROOT)$(php_fpm_init_path)
+
+	@test -d /etc/nginx/ && \
+	echo "Installing NGINX sample config:   /etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/etc/nginx/ && \
+	echo "Installing NGINX sample config:   /usr/local/etc/nginx/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /usr/local/etc/nginx/nginx-site-conf.sample
+
+	@test -d /usr/local/nginx/conf/ && \
+	echo "Installing NGINX sample config:   /usr/local/nginx/conf/nginx-site-conf.sample" && \
+	@$(INSTALL_DATA) -b nginx-site-conf.sample /usr/local/nginx/conf/nginx-site-conf.sample
+
 	@echo ""
 	@echo "*** FPM Installation complete. ***"
 	@echo ""
-ifneq ($(strip $(php_fpm_init)),)
-	@echo "run:"
-	@echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`"
-	@echo ""
-	@echo "or system equivalent to start the $(php_fpm_init) service."
-	@echo ""
-@ENDIF@
+
+	@test "$(php_fpm_init)" && \
+	echo "run:" && \
+	echo "\`update-rc.d $(php_fpm_init) defaults; invoke-rc.d $(php_fpm_init) start\`" && \
+	echo "" && \
+	echo "or system equivalent to start the $(php_fpm_init) service." && \
+	echo ""
 # Tell versions [3.59,3.63) of GNU make to not export all variables.
 # Otherwise a system limit (for SysV at least) may be exceeded.
 .NOEXPORT:
--- php-fpm-rev-93/readme.markdown
+++ php-fpm/readme.markdown
@@ -78,7 +78,7 @@
 	--with-libevent[=PATH]       Path to the libevent, for fpm SAPI [/usr/local]
 	--with-fpm-bin[=PATH]        Set the path for the php-fpm binary [/usr/local/bin/php-fpm]
 	--with-fpm-port[=PORT]       Set the tcp port number to listen for cgi requests [9000]
-	--with-fpm-conf[=PATH]       Set the path for the php-fpm configuration file [/etc/php-fpm.conf]
+	--with[out]-fpm-conf[=PATH]  Set the path for the php-fpm configuration file [/etc/php-fpm.conf]
 	--with[out]-fpm-init[=PATH]  Set the path for the php-fpm init file [/etc/init.d/php-fpm]
 	--with-fpm-log[=PATH]        Set the path for the php-fpm log file [/var/log/php-fpm.log]
 	--with-fpm-pid[=PATH]        Set the path for the php-fpm pid file [/var/run/php-fpm.pid]
@@ -99,6 +99,14 @@
 	# Install into '/opt'
 	sudo INSTALL_ROOT=/opt make install
 
+Notes:
+
+* (Upgrade) When overwriting existing FPM installation files: A previous configuration file `php-fpm.conf` will be moved to `php-fpm.conf.old`. Then a newer (default) configuration file will be installed in it's place. If you have any custom XML settings which you wish to keep, its recommended to copy these back over manually.
+
+* (BSD) the default init.d path is `/usr/local/etc/rc.d/php-fpm` or disable: `--without-fpm-init`
+
+* (Nginx) An example nginx configuration file is generated. The file `nginx-site-conf.sample` may be installed into your nginx configuration directory, if exists: `/etc/nginx/`, `/usr/local/etc/nginx/`, or `/usr/local/nginx/conf`
+
 ## More about the PHP-FPM Build process
 
 The make process can be described as:
--- php-fpm-rev-93/readme-ru.markdown
+++ php-fpm/readme-ru.markdown
@@ -71,7 +71,7 @@
 	--with-libevent[=PATH]       Путь до libevent, для fpm SAPI [/usr/local]
 	--with-fpm-bin[=PATH]        Путь для откомпилированного php-fpm [/usr/local/bin/php-fpm]
 	--with-fpm-port[=PORT]       TCP порт для cgi запросов [9000]
-	--with-fpm-conf[=PATH]       Путь до файла конфигурации php-fpm [/etc/php-fpm.conf]
+	--with[out]-fpm-conf[=PATH]  Путь до файла конфигурации php-fpm [/etc/php-fpm.conf]
 	--with[out]-fpm-init[=PATH]  Путь до init-файла php-fpm [/etc/init.d/php-fpm]
 	--with-fpm-log[=PATH]        Путь до лог-файла php-fpm [/var/log/php-fpm.log]
 	--with-fpm-pid[=PATH]        Путь до pid-файла php-fpm [/var/run/php-fpm.pid]
@@ -92,6 +92,14 @@
 	# Установить в '/opt'
 	sudo INSTALL_ROOT=/opt make install
 
+Notes:
+
+* (Upgrade) When overwriting existing FPM installation files: A previous configuration file `php-fpm.conf` will be moved to `php-fpm.conf.old`. Then a newer (default) configuration file will be installed in it's place. If you have any custom XML settings which you wish to keep, its recommended to copy these back over manually.
+
+* (BSD) the default init.d path is `/usr/local/etc/rc.d/php-fpm` or disable: `--without-fpm-init`
+
+* (Nginx) An example nginx configuration file is generated. The file `nginx-site-conf.sample` may be installed into your nginx configuration directory, if exists: `/etc/nginx/`, `/usr/local/etc/nginx/`, or `/usr/local/nginx/conf`
+
 ## Больше о процессе сборки PHP-FPM
 
 Процесс сборки можно описать так:
